@@ -1,6 +1,88 @@
+#' Sensitivity analysis to correct for unknown or unmeasured confounding with
+#' effect modification
+#'
+#' Simple sensitivity analysis to correct for unknown or unmeasured confounding
+#' with effect measure modification. Implementation for ratio measures (relative
+#' risk -- RR, or odds ratio -- OR) and difference measures (risk difference -- RD).
+#'
+#' @param exposed Exposure variable. If a variable, this variable is tabulated against.
+#' @param case Outcome variable.
+#' @param implement Deprecated. Please use type instead.
+#' @param type Choice of implementation, with no effect measure modification for
+#' ratio measures (relative risk -- RR; odds ratio -- OR) or difference measures
+#' (risk difference -- RD).
+#' @param p Numeric vector defining the prevalence of the confounder. This vector
+#' has 2 elements between 0 and 1, in the following order:
+#' \enumerate{
+#' \item Prevalence of the confounder among the exposed, and
+#' \item Prevalence of the confounder among the unexposed.
+#' }
+#' @param RR.cd Vector defining the confounder-disease relative risk. This vector
+#' has two elements between 0 and 1, in the following order:
+#' \enumerate{
+#' \item Among the exposed, and
+#' \item among the unexposed.
+#' }
+#' @param OR.cd Vector defining the confounder-disease odds ratio. This vector
+#' has two elements between 0 and 1, in the folowing order:
+#' \enumerate{
+#' \item Among the exposed, and
+#' \item among the unexposed.
+#' }
+#' @param RD.cd Vector dfining the confounder-disease risk difference. This vector
+#' has two elements between 0 and 1, in the following order:
+#' \enumerate{
+#' \item Among the exposed, and
+#' \item among the unexposed.
+#' }
+#' @param alpha Significance level.
+#' @param dec Number of decimals in the printout.
+#' @param print A logical scalar. Should the results be printed?
+#' 
+#' @return A list with elements:
+#' \item{obs.data}{The analysed 2 x 2 table from the observed data.}
+#' \item{cfder.data}{The same table for Confounder +.}
+#' \item{nocfder.data}{The same table for Confounder -.}
+#' \item{obs.measures}{A table of relative risk with confidence intervals; Total,
+#' for Confoundner +, and for Confounder -.}
+#' \item{adj.measures}{A table of Standardized Morbidity Ratio and Mantel-Haenszel
+#' estimates.}
+#' \item{bias.parms}{Input bias parameters.}
+#'
+#' @references Lash, T.L., Fox, M.P, Fink, A.K., 2009 \emph{Applying Quantitative
+#' Bias Analysis to Epidemiologic Data}, pp.59--78, Springer.
+#' 
+#' @examples
+#' # The data for this example come from:
+#' # Tyndall M.W., Ronald A.R., Agoki E., Malisa W., Bwayo J.J., Ndinya-Achola J.O.
+#' # et al.
+#' # Increased risk of infection with human immunodeficiency virus type 1 among
+#' # uncircumcised men presenting with genital ulcer disease in Kenya.
+#' # Clin Infect Dis 1996;23:449-53.
+#' confounders.emm(matrix(c(105, 85, 527, 93),
+#' dimnames = list(c("HIV+", "HIV-"), c("Circ+", "Circ-")),
+#' nrow = 2, byrow = TRUE),
+#' type = "RR",
+#' p = c(.8, .05),
+#' RR.cd = c(.4, .7))
+#' confounders.emm(matrix(c(105, 85, 527, 93),
+#' dimnames = list(c("HIV+", "HIV-"), c("Circ+", "Circ-")),
+#' nrow = 2, byrow = TRUE),
+#' type = "OR",
+#' p = c(.8, .05),
+#' OR.cd = c(.4, .7))
+#' confounders.emm(matrix(c(105, 85, 527, 93),
+#' dimnames = list(c("HIV+", "HIV-"), c("Circ+", "Circ-")),
+#' nrow = 2, byrow = TRUE),
+#' type = "RD",
+#' p = c(.8, .05),
+#' RD.cd = c(-.6, -.3))
+#' @export
+#' @importFrom stats qnorm
 confounders.emm <- function(exposed,
                             case,
                             implement = c("RR", "OR", "RD"),
+                            type = c("RR", "OR", "RD"),
                             p = NULL,
                             RR.cd = NULL,
                             OR.cd = NULL,
@@ -8,14 +90,19 @@ confounders.emm <- function(exposed,
                             alpha = 0.05,
                             dec = 4,
                             print = TRUE){
-    if(length(implement) > 1)
-        stop('Choose between RR, OR, or RD implementation.')
-    if(implement == "RR" & (!is.null(OR.cd) | !is.null(RD.cd)))
-        stop('Mismatch between implementation type and confounder risk.')
-    if(implement == "OR" & (!is.null(RR.cd) | !is.null(RD.cd)))
-        stop('Mismatch between implementation type and confounder risk.')
-    if(implement == "RD" & (!is.null(RR.cd) | !is.null(OR.cd)))
-        stop('Mismatch between implementation type and confounder risk.')
+    if (!missing(implement)) {
+        warning("Argument implement is deprecated; please use type instead.", 
+                call. = FALSE)
+        type <- implement
+  }
+    if(length(type) > 1)
+        stop('Choose between RR, OR, or RD typeation.')
+    if(type == "RR" & (!is.null(OR.cd) | !is.null(RD.cd)))
+        stop('Mismatch between typeation type and confounder risk.')
+    if(type == "OR" & (!is.null(RR.cd) | !is.null(RD.cd)))
+        stop('Mismatch between typeation type and confounder risk.')
+    if(type == "RD" & (!is.null(RR.cd) | !is.null(OR.cd)))
+        stop('Mismatch between typeation type and confounder risk.')
     
     if(is.null(p))
         p <- c(0, 0)
@@ -50,13 +137,15 @@ confounders.emm <- function(exposed,
     if(inherits(exposed, c("table", "matrix")))
         tab <- exposed
     else tab <- table(exposed, case)
+    tab <- tab[1:2, 1:2]
+
     a <- tab[1, 1]
     b <- tab[1, 2]
     c <- tab[2, 1]
     d <- tab[2, 2]
 
-    implement <- match.arg(implement)
-    if (implement == "RR") {
+    type <- match.arg(type)
+    if (type == "RR") {
         crude.rr <- (a/(a + c)) / (b/(b + d))
         se.log.crude.rr <- sqrt((c/a) / (a+c) + (d/b) / (b+d))
         lci.crude.rr <- exp(log(crude.rr) - qnorm(1 - alpha/2) * se.log.crude.rr)
@@ -77,7 +166,7 @@ confounders.emm <- function(exposed,
 
         if(A1 < 0 | B1 < 0 | C1 < 0 | D1 < 0 |
            A0 < 0 | B0 < 0 | C0 < 0 | D0 < 0)
-            stop('Negative cell.')
+            stop('Parameters chosen lead to negative cell(s) in adjusted 2x2 table(s).')
         
         tab.cfder <- matrix(c(A1, B1, C1, D1), nrow = 2, byrow = TRUE)
         tab.nocfder <- matrix(c(A0, B0, C0, D0), nrow = 2, byrow = TRUE)
@@ -168,7 +257,7 @@ confounders.emm <- function(exposed,
                             "Relative Risk, Confounder -:")
     }
     
-    if (implement == "OR"){
+    if (type == "OR"){
         crude.or <- (a/b) / (c/d)
         se.log.crude.or <- sqrt(1/a + 1/b + 1/c + 1/d)
         lci.crude.or <- exp(log(crude.or) - qnorm(1 - alpha/2) * se.log.crude.or)
@@ -189,7 +278,7 @@ confounders.emm <- function(exposed,
 
         if(A1 < 0 | B1 < 0 | C1 < 0 | D1 < 0 |
            A0 < 0 | B0 < 0 | C0 < 0 | D0 < 0)
-            stop('Negative cell.')
+            stop('Parameters chosen lead to negative cell(s) in adjusted 2x2 table(s).')
         
         tab.cfder <- matrix(c(A1, B1, C1, D1), nrow = 2, byrow = TRUE)
         tab.nocfder <- matrix(c(A0, B0, C0, D0), nrow = 2, byrow = TRUE)
@@ -280,7 +369,7 @@ confounders.emm <- function(exposed,
                             "Odds Ratio, Confounder -:")
     }
     
-    if (implement == "RD"){
+    if (type == "RD"){
         crude.rd <- (a / (a + c)) - (b / (b + d))
         se.log.crude.rd <- sqrt((a * c) / (a + c)^3 + (b * d) / (b + d)^3)
         lci.crude.rd <- crude.rd - qnorm(1 - alpha/2) * se.log.crude.rd
@@ -301,7 +390,7 @@ confounders.emm <- function(exposed,
 
         if(A1 < 0 | B1 < 0 | C1 < 0 | D1 < 0 |
            A0 < 0 | B0 < 0 | C0 < 0 | D0 < 0)
-            stop('Negative cell.')
+            stop('Parameters chosen lead to negative cell(s) in adjusted 2x2 table(s).')
         
         tab.cfder <- matrix(c(A1, B1, C1, D1), nrow = 2, byrow = TRUE)
         tab.nocfder <- matrix(c(A0, B0, C0, D0), nrow = 2, byrow = TRUE)
