@@ -1,3 +1,42 @@
+#' Sensitivity analysis to correct for selection bias.
+#'
+#' Simple sensitivity analysis to correct for selection bias using estimates of
+#' the selection proportions.
+#'
+#' @param exposed Exposure variable. If a variable, this variable is tabulated
+#' against.
+#' @param case Outcome variable.
+#' @param selprob Numeric vector defining the selection probabilities. This vector has 4 elements between 0 and 1, in the following order:
+#' \enumerate{
+#' \item Selection probability among cases exposed,
+#' \item Selection probability among cases unexposed,
+#' \item Selection probabillity among noncases exposed, and
+#' \item Selection probability among noncases unexposed.
+#' }
+#' @param alpha Significance level.
+#' @param dec Number of decimals in the printout.
+#' @param print A logical scalar. Should the results be printed?
+#' 
+#' @return A list with elements:
+#' \item{obs.data}{The analysed 2 x 2 table from the observed data.}
+#' \item{corr.data}{The same table corrected for  selection proportions.}
+#' \item{obs.measures}{A table of odds ratios and relative risk with confidence intervals.}
+#' \item{adj.measures}{Selection bias corrected measures of outcome-exposure relationship.}
+#' \item{bias.parms}{Input bias parameters: selection probabilities.}
+#'
+#' @examples
+#' # The data for this example come from:
+#' # Stang A., Schmidt-Pokrzywniak A., Lehnert M., Parkin D.M., Ferlay J., Bornfeld N.
+#' # et al.
+#' # Population-based incidence estimates of uveal melanoma in Germany. Supplementing
+#' # cancer registry data by case-control data.
+#' # Eur J Cancer Prev 2006;15:165-70.
+#' selection(matrix(c(136, 107, 297, 165),
+#' dimnames = list(c("UM+", "UM-"), c("Mobile+", "Mobile-")),
+#' nrow = 2, byrow = TRUE),
+#' selprob = c(.94, .85, .64, .25))
+#' @export
+#' @importFrom stats qnorm
 selection <- function(exposed,
                       case,
                       selprob = NULL,
@@ -17,6 +56,7 @@ selection <- function(exposed,
     if(inherits(exposed, c("table", "matrix")))
         tab <- exposed
     else tab <- table(exposed, case)
+    tab <- tab[1:2, 1:2]
 
     a <- tab[1, 1]
     b <- tab[1, 2]
